@@ -1548,12 +1548,13 @@ static void isicom_close(struct tty_struct * tty, struct file * filp)
 		return;
 	}
 
-#if LINUX_VERSION_CODE < 132118	
-				/* Changed by Ravindra as per the definition 
-				   of tty->count in Fedora core */
-	if ((tty->count == 1) && (port->count != 1)) {
-#else		
+/* Changed by Ravindra as per the definition of tty->count in Fedora core */
+
+
+#if defined(ATOMIC_COUNT)	
 	if ((atomic_read(&tty->count) == 1) && (port->count != 1)) {
+#else		
+	if ((tty->count == 1) && (port->count != 1)) {
 #endif
 		
 		printk(KERN_WARNING "ISICOM:(0x%x) isicom_close: bad port count"
